package com.atguigu.ssyx.acl.controller;

import com.atguigu.ssyx.acl.service.PermissionService;
import com.atguigu.ssyx.common.result.Result;
import com.atguigu.ssyx.model.acl.Permission;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/admin/acl/permission")
@Api(tags = "菜单管理")
@Slf4j
public class PermissionController {
    @Autowired
    private PermissionService permissionService;

    @ApiOperation(value = "获取菜单")
    @GetMapping
    public Result<List<Permission>> index() {
        List<Permission> list = permissionService.queryAllMenu();
        return Result.success(list);
    }

    @ApiOperation(value = "新增菜单")
    @PostMapping("save")
    public Result<Permission> save(@RequestBody Permission permission) {
        permissionService.save(permission);
        return Result.success();
    }

    @ApiOperation(value = "修改菜单")
    @PutMapping("update")
    public Result<Permission> updateById(@RequestBody Permission permission) {
        permissionService.updateById(permission);
        return Result.success();
    }

    @ApiOperation(value = "递归删除菜单")
    @DeleteMapping("remove/{id}")
    public Result<Permission> remove(@PathVariable Long id) {
        permissionService.removeChildById(id);
        return Result.success();
    }

    @ApiOperation(value = "查询所有菜单和角色分配菜单")
    @GetMapping("toAssign/{roleId}")
    public Result<List<Permission>> toAssign(@PathVariable Long roleId) {
        List<Permission> permissionList = permissionService.findMenuByRoleId(roleId);
        return Result.success(permissionList);
    }

    @ApiOperation(value = "查询所有菜单和角色分配菜单")
    @PostMapping("doAssign")
    public Result<Permission> doAssign(@RequestParam Long roleId,
                                       @RequestParam List<Long> permissions) {
        permissionService.doAssign(roleId, permissions);
        return Result.success();
    }
}
