package com.atguigu.ssyx.activity.controller;


import com.atguigu.ssyx.activity.service.SecKillService;
import com.atguigu.ssyx.common.result.Result;
import com.atguigu.ssyx.model.activity.Seckill;
import com.atguigu.ssyx.vo.activity.SeckillQueryVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 秒杀活动 前端控制器
 * </p>
 *
 * @author bunny
 * @since 2024-04-06
 */
@Api(value = "Seckill管理", tags = "Seckill管理")
@RestController
@RequestMapping(value = "/admin/activity/seckill")
public class SecKillController {
    @Autowired
    private SecKillService secKillService;

    @ApiOperation(value = "获取分页列表")
    @GetMapping("{page}/{limit}")
    public Result<IPage<Seckill>> index(
            @ApiParam(name = "page", value = "当前页码", required = true)
            @PathVariable Long page,
            @ApiParam(name = "limit", value = "每页记录数", required = true)
            @PathVariable Long limit,
            @ApiParam(name = "seckillQueryVo", value = "查询对象", required = false)
            SeckillQueryVo seckillQueryVo) {
        Page<Seckill> pageParam = new Page<>();
        IPage<Seckill> pageModel = secKillService.selectPage(pageParam, seckillQueryVo);
        return Result.success(pageModel);
    }

    @ApiOperation(value = "获取")
    @GetMapping("get/{id}")
    public Result<Seckill> getSecKill(@PathVariable Long id) {
        Seckill seckill = secKillService.getById(id);
        return Result.success(seckill);
    }

    @ApiOperation(value = "新增")
    @PostMapping("save")
    public Result<Seckill> save(@RequestBody Seckill seckill) {
        secKillService.save(seckill);
        return Result.success();
    }

    @ApiOperation(value = "修改")
    @PutMapping("update")
    public Result<Seckill> updateById(@RequestBody Seckill seckill) {
        secKillService.updateById(seckill);
        return Result.success();
    }

    @ApiOperation(value = "删除")
    @DeleteMapping("remove/{id}")
    public Result<Seckill> removeById(@PathVariable Long id) {
        secKillService.removeById(id);
        return Result.success();
    }

    @ApiOperation(value = "根据id列表删除")
    @DeleteMapping("batchRemove")
    public Result<Seckill> batchRemove(@RequestBody List<Long> ids) {
        secKillService.removeByIds(ids);
        return Result.success();
    }

    @ApiOperation(value = "更新状态")
    @PostMapping("updateStatus/{id}/{status}")
    public Result<Seckill> updateStatus(@PathVariable Long id, @PathVariable Integer status) {
        secKillService.updateStatus(id, status);
        return Result.success();
    }
}

