package com.atguigu.ssyx.activity.service;

import com.atguigu.ssyx.model.activity.CouponInfo;
import com.atguigu.ssyx.model.order.CartInfo;
import com.atguigu.ssyx.vo.activity.CouponRuleVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 优惠券信息 服务类
 * </p>
 *
 * @author bunny
 * @since 2024-04-04
 */
public interface CouponInfoService extends IService<CouponInfo> {

    /**
     * * 获取分页列表
     *
     * @param pageParam 查询分页条件
     * @return 分页结果
     */
    IPage<CouponInfo> selectPage(Page<CouponInfo> pageParam);

    /**
     * 获取优惠券
     *
     * @param id 优惠卷Id
     * @return 优惠卷
     */
    CouponInfo getCouponInfo(Long id);

    /**
     * 获取优惠券信息
     *
     * @param id 优惠卷Id
     * @return Map<String, Object>
     */
    Map<String, Object> findCouponRuleList(Long id);

    /**
     * * 新增活动
     *
     * @param couponRuleVo 新的活动
     */
    void saveCouponRule(CouponRuleVo couponRuleVo);

    /**
     * 根据关键字获取sku列表，活动使用
     *
     * @param keyword 关键字
     * @return 根据关键字获取sku列表，活动使用
     */
    List<CouponInfo> findCouponByKeyword(String keyword);

    /**
     * * 获取优惠券信息
     *
     * @param skuId  商品id
     * @param userId 用户id
     * @return 优惠卷列表
     */
    List<CouponInfo> findCouponInfo(Long skuId, Long userId);

    /**
     * * 购物车可使用的优惠券列表
     *
     * @param cartInfoList 购物车列表信息
     * @param userId       用户ID
     * @return List<CouponInfo>
     */
    List<CouponInfo> findCartCouponInfo(List<CartInfo> cartInfoList, Long userId);
}
