package com.atguigu.ssyx.cart.service;

import com.atguigu.ssyx.model.order.CartInfo;

import java.util.List;

public interface CartInfoService {

    /**
     * * 添加购物车
     *
     * @param skuId  商品id
     * @param userId 用户id
     * @param skuNum 商品数量
     */
    void addToCart(Long skuId, Long userId, Integer skuNum);

    /**
     * * 删除购物车内容
     *
     * @param skuId  商品id
     * @param userId 用户id
     */
    void deleteCart(Long skuId, Long userId);

    /**
     * * 清空购物车
     *
     * @param userId 用户id
     */
    void deleteAllCart(Long userId);

    /**
     * * 批量删除购物车
     *
     * @param userId    用户id
     * @param skuIdList 商品的id列表
     */
    void batchDeleteCart(Long userId, List<Long> skuIdList);

    /**
     * * 查询购物车列表
     *
     * @param userId 用户id
     * @return 购物车信息列表
     */
    List<CartInfo> getCartList(Long userId);

    /**
     * * 更新选中状态
     *
     * @param userId    用户id
     * @param isChecked 是否选中
     * @param skuId     商品Id
     */
    void checkCart(Long userId, Integer isChecked, Long skuId);

    /**
     * * 更新全部选中
     *
     * @param userId    用户id
     * @param isChecked 是否选中
     */
    void checkAllCart(Long userId, Integer isChecked);

    /**
     * * 批量选择购物车
     *
     * @param skuIdList 商品的id列表
     * @param userId    用户id
     * @param isChecked 是否选中
     */
    void batchCheckCart(List<Long> skuIdList, Long userId, Integer isChecked);

    /**
     * * 根据用户Id查询购物车列表
     * @param userId 用户ID
     * @return 购物车列表
     */
    List<CartInfo> getCartCheckedList(Long userId);
}

