package com.atguigu.ssyx.home.service.impl;

import com.atguigu.ssyx.client.product.ProductFeignClient;
import com.atguigu.ssyx.client.search.SearchFeignClient;
import com.atguigu.ssyx.client.user.UserFeignClient;
import com.atguigu.ssyx.home.service.HomeService;
import com.atguigu.ssyx.model.product.Category;
import com.atguigu.ssyx.model.product.SkuInfo;
import com.atguigu.ssyx.model.search.SkuEs;
import com.atguigu.ssyx.vo.user.LeaderAddressVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class HomeServiceImpl implements HomeService {
    @Autowired
    private UserFeignClient userFeignClient;
    @Autowired
    private ProductFeignClient productFeignClient;
    @Autowired
    private SearchFeignClient searchFeignClient;

    /**
     * 获取首页数据
     *
     * @param userId 用户Id
     * @return Map<String, Object>
     */
    @Override
    public Map<String, Object> home(Long userId) {
        Map<String, Object> result = new HashMap<>();
        // 远程调用模块获取需要数据
        LeaderAddressVo leaderAddressVo = userFeignClient.getLeaderAddressByUserId(userId);
        result.put("leaderAddress", leaderAddressVo);

        // 获取全部商品分类
        List<Category> categoryList = productFeignClient.findAllCategoryList().getData();
        result.put("categoryList", categoryList);

        // 获取新人专享
        List<SkuInfo> personSkuInfoList = productFeignClient.findNewPersonSkuInfoList().getData();
        result.put("personSkuInfoList", personSkuInfoList);

        // 使用评分查询-ES
        List<SkuEs> hotSkuList = searchFeignClient.findHotSkuList();
        result.put("hotSkuList", hotSkuList);

        // 2.获取分类
        return result;
    }
}
