package com.atguigu.ssyx.product.service;

import com.atguigu.ssyx.model.product.SkuInfo;
import com.atguigu.ssyx.vo.product.SkuInfoQueryVo;
import com.atguigu.ssyx.vo.product.SkuInfoVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.List;

/**
 * <p>
 * sku信息 服务类
 * </p>
 *
 * @author bunny
 * @since 2024-04-03
 */
public interface SkuInfoService extends IService<SkuInfo> {

    /**
     * 获取sku分页列表
     *
     * @param pageParam      分页查询条件
     * @param skuInfoQueryVo 商品查询条件
     * @return 分页结果
     */
    IPage<SkuInfo> selectPage(Page<SkuInfo> pageParam, SkuInfoQueryVo skuInfoQueryVo);

    /**
     * 商品添加方法
     *
     * @param skuInfoVo 商品信息
     */
    void saveSkuInfo(SkuInfoVo skuInfoVo);

    /**
     * 获取商品SKU信息
     *
     * @param id 商品id
     * @return 商品信息
     */
    SkuInfoVo getSkuInfoVo(Long id);

    /**
     * 修改商品sku信息
     *
     * @param skuInfoVo 商品信息
     */
    void updateSkuInfo(SkuInfoVo skuInfoVo);

    /**
     * 商品审核
     *
     * @param skuId  商品ID
     * @param status 商品状态
     */
    void check(Long skuId, Integer status);

    /**
     * 商品上架
     *
     * @param skuId  商品ID
     * @param status 商品状态
     */
    void publish(Long skuId, Integer status);

    /**
     * 新人专享
     *
     * @param skuId  商品ID
     * @param status 商品状态
     */
    void isNewPerson(Long skuId, Integer status);

    /**
     * 根据skuId得到sku信息列表
     *
     * @param skuIdList skuId
     * @return List<SkuInfo>
     */
    List<SkuInfo> findSkuInfoList(List<Long> skuIdList);

    /**
     * 根据关键字获取sku列表
     *
     * @param keyword 关键字
     * @return List<SkuInfo>
     */
    List<SkuInfo> findSkuInfoByKeyword(String keyword);

    /**
     * * 获取新人专享
     *
     * @return 新人专享
     */
    List<SkuInfo> findNewPersonList();
}
