package com.atguigu.ssyx.user.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.atguigu.common.utils.JwtHelper;
import com.atguigu.ssyx.common.constant.RedisConst;
import com.atguigu.ssyx.common.context.BaseContext;
import com.atguigu.ssyx.common.exception.BunnyException;
import com.atguigu.ssyx.common.result.ResultCodeEnum;
import com.atguigu.ssyx.enums.UserType;
import com.atguigu.ssyx.model.user.User;
import com.atguigu.ssyx.user.service.UserService;
import com.atguigu.ssyx.user.service.WeiXinApiService;
import com.atguigu.ssyx.user.service.module.WeiXinApiServiceModule;
import com.atguigu.ssyx.user.utils.HttpClientUtils;
import com.atguigu.ssyx.vo.user.LeaderAddressVo;
import com.atguigu.ssyx.vo.user.UserLoginVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;

@Service
@Slf4j
public class WeiXinApiServiceImpl implements WeiXinApiService {
    @Autowired
    private WeiXinApiServiceModule module;
    @Autowired
    private UserService userService;
    @Autowired
    private RedisTemplate<String, Object> redisTemplate;

    /**
     * * 微信登录获取openid
     *
     * @param code 登录码
     */
    @Override
    public Map<String, Object> callback(String code) {
        // 拿到微信返回code临时票据纸
        String accessTokenUrl = module.getAccessTokenUrl(code);
        try {
            String result = HttpClientUtils.get(accessTokenUrl);
            // 请求微信接口服，返回两个值 session_key 和 openId
            JSONObject jsonObject = JSONObject.parseObject(result);
            // String accessToken = jsonObject.getString("session_key");
            String openId = jsonObject.getString("openid");
            // 先根据openid进行数据库查询
            User user = userService.getUserByOpenId(openId);
            // 如果没有查到用户信息,那么调用微信个人信息获取的接口
            if (null == user) {
                user = new User();
                user.setOpenId(openId);
                user.setNickName(openId);
                user.setPhotoUrl("");
                user.setUserType(UserType.USER);
                user.setIsNew(0);
                userService.save(user);
            }
            // 根据用户Id查询默认团长Id
            LeaderAddressVo leaderAddressVo = userService.getLeaderAddressVoByUserId(user.getId());
            Map<String, Object> map = new HashMap<>();
            String name = user.getNickName();
            map.put("user", user);
            map.put("leaderAddressVo", leaderAddressVo);
            String token = JwtHelper.createToken(user.getId(), name);
            map.put("token", token);

            // 获取当前用户登录信息
            UserLoginVo userLoginVo = userService.getUserLoginVo(user.getId());
            redisTemplate.opsForValue().set(RedisConst.USER_LOGIN_KEY_PREFIX + user.getId(), userLoginVo, RedisConst.USERKEY_TIMEOUT, TimeUnit.DAYS);
            return map;
        } catch (Exception exception) {
            throw new BunnyException(ResultCodeEnum.FETCH_ACCESSTOKEN_FAILD);
        }
    }

    /**
     * * 更新用户昵称与头像
     *
     * @param user 用户信息
     */
    @Override
    public void updateUser(User user) {
        User userServiceById = userService.getById(BaseContext.getUserId());
        userServiceById.setNickName(user.getNickName().replaceAll("[ue000-uefff]", "*"));
        userServiceById.setPhotoUrl(user.getPhotoUrl());
        userService.updateById(userServiceById);
    }
}
